@@ -225,7 +225,14 @@ class PlaywrightTool(BaseTool):
             if self._browser_context is None:
                 raise RuntimeError("Browser context failed to initialize")
 
-            self.page = await self._browser_context.new_page()
+            # Reuse existing page if available (for CDP connections), otherwise create new one
+            pages = self._browser_context.pages
+            if pages:
+                self.page = pages[0]
+                logger.info("Reusing existing browser page")
+            else:
+                self.page = await self._browser_context.new_page()
+                logger.info("Created new browser page")
             logger.info("Playwright browser launched successfully")
 
     async def navigate(
